==> ws-v3.50.4-src.tar.gz: ws-v3.50-4/include/WSCvline.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVLINE_H
#define WSCVLINE_H

#include <WScom.h>
#include <WSCnwbase.h>
#define WSCvline_VER  1000

class WSCvline :public WSCnwbase{

  protected:
    WSCushort _lw;
    char* _data_x;
    char* _data_y;
    short*	_line_x;
    short*	_line_y;
    WSCuchar   _line_num;
    unsigned   _lt:4;

    WSMFpropertyDef(WSNlineWidth, WSCushort, _lw);
    WSMFpropertyDef(WSNlineType,  WSCuchar,  _lt);
    WSMFpropertyDef(WSNlineX,   char*, _data_x  );
    WSMFpropertyDef(WSNlineY,   char*, _data_y  );
    WSMFpropertyDef(WSNlineNum, WSCuchar, _line_num);

    long _set_data_num(short num);

  public:
    WSCvline(WSCbase* base, char* name);
    virtual ~WSCvline();

    virtual long draw();

    //used by vpoly...
    static long _str_to_addr(char* str, short* data,short num);

    WSMFguiClassDef(WSCvline, WSCnwbase);
    WSMFversionDef  (WSCvline);
};

#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCvline.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCVLINE_H
#define WSCVLINE_H

#include <WScom.h>
#include <WSCnwbase.h>
#define WSCvline_VER  1000

class WSCvline :public WSCnwbase{

  protected:
    WSCushort _lw;
    char* _data_x;
    char* _data_y;
    short*	_line_x;
    short*	_line_y;
    WSCuchar   _line_num;
    unsigned   _lt:4;

    WSMFpropertyDef(WSNlineWidth, WSCushort, _lw);
    WSMFpropertyDef(WSNlineType,  WSCuchar,  _lt);
    WSMFpropertyDef(WSNlineX,   char*, _data_x  );
    WSMFpropertyDef(WSNlineY,   char*, _data_y  );
    WSMFpropertyDef(WSNlineNum, WSCuchar, _line_num);

    WSDLEX32 long _set_data_num(short num);

  public:
    WSDLEX32 WSCvline(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvline();

    WSDLEX32 virtual long draw();

    //used by vpoly...
    WSDLEX32 static long _str_to_addr(char* str, short* data,short num);

    WSMFguiClassDef(WSCvline, WSCnwbase);
    WSMFversionDef  (WSCvline);
};

#endif
